==> thx_organization-0.0.2.tar.gz: thx_organization-0.0.2/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['thx',
 'thx.organization',
 'thx.organization.api',
 'thx.organization.api.version1',
 'thx.organization.management',
 'thx.organization.management.commands',
 'thx.organization.migrations',
 'thx.organization.models',
 'thx.organization.tests']

package_data = \
{'': ['*'],
 'thx.organization': ['docs/*',
                      'locale/*',
                      'locale/it/LC_MESSAGES/*',
                      'static/organization/admin/*',
                      'static/organization/img/*',
                      'static/organization/lib/*',
                      'static/organization/src/*',
                      'templates/admin/contact_document/*',
                      'templates/includes/*',
                      'templates/organization/*']}

install_requires = \
['Django>=2,<4',
 'django-application-settings>=0.2',
 'jmb.filters>=1.2.5',
 'thx-address>=0.0.6',
 'thx-admin-tools>=0.2.1',
 'thx-carriage>=0.0.4',
 'thx-core>=0.1',
 'thx-currency>=0.0.7',
 'thx-i18n>=0.0.6',
 'thx-l10n>=0.0.7',
 'thx-office>=0.0.4',
 'thx-payment>=0.0.4',
 'thx-vat>=0.0.6']

setup_kwargs = {
    'name': 'thx-organization',
    'version': '0.0.2',
    'description': '',
    'long_description': 'None',
    'author': 'THUX',
    'author_email': 'code@thux.it',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)

==> thx_organization-0.1.0.tar.gz: thx_organization-0.1.0/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['thx',
 'thx.organization',
 'thx.organization.api',
 'thx.organization.api.version1',
 'thx.organization.management',
 'thx.organization.management.commands',
 'thx.organization.migrations',
 'thx.organization.models',
 'thx.organization.tests']

package_data = \
{'': ['*'],
 'thx.organization': ['docs/*',
                      'locale/*',
                      'locale/it/LC_MESSAGES/*',
                      'static/organization/admin/*',
                      'static/organization/img/*',
                      'static/organization/lib/*',
                      'static/organization/src/*',
                      'templates/admin/contact_document/*',
                      'templates/includes/*',
                      'templates/organization/*']}

install_requires = \
['Django>=2,<4',
 'django-application-settings>=0.2',
 'jmb-filters>=1.3.0,<2.0.0',
 'thx-address>=0.1.2,<0.2.0',
 'thx-admin-tools>=0.2.1',
 'thx-api>=0.3.12,<0.4.0',
 'thx-carriage>=0.0.4',
 'thx-core>=0.2.12',
 'thx-currency>=0.0.7',
 'thx-i18n>=0.0.6',
 'thx-l10n>=0.0.7',
 'thx-office>=0.0.4',
 'thx-payment>=0.0.4',
 'thx-swapper>=0.0.2',
 'thx-vat>=0.0.6']

setup_kwargs = {
    'name': 'thx-organization',
    'version': '0.1.0',
    'description': '',
    'long_description': 'None',
    'author': 'THUX',
    'author_email': 'code@thux.it',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
